@@ -25,12 +25,12 @@ from libreflow.baseflow.runners import (
     Blender,
     SessionWorker,
     DefaultEditor,
-    DefaultRunners
+    DefaultRunners,
 )
 
 from .entity_manager import EntityManager
 from .film import Film
-from .shot import Sequence, Shot
+from .shot import Shot
 from .task import Task
 from .users import User
 from .file import (
@@ -39,6 +39,11 @@ from .file import (
     Revision,
     TrackedFolderRevision,
 )
+from .runners import (
+    DefaultRunners,
+    Palas,
+    Houdoo,
+)
 
 
 class ProjectSettings(BaseProjectSettings):
@@ -104,12 +109,12 @@ class Project(flow.Object):
     def _injection_provider(cls, slot_name, default_type):
         if slot_name == 'libreflow.baseflow.film.Film':
             return Film
-        elif slot_name == 'libreflow.baseflow.shot.Sequence':
-            return Sequence
         elif slot_name == 'libreflow.baseflow.shot.Shot':
             return Shot
-        elif slot_name == 'libreflow.baseflow.file.ManagedTask':
+        elif slot_name == 'libreflow.baseflow.task.ManagedTask':
             return Task
+        elif slot_name == 'libreflow.baseflow.runners.DefaultRunners':
+            return DefaultRunners
         elif slot_name == 'libreflow.baseflow.file.TrackedFile':
             return TrackedFile
         elif slot_name == 'libreflow.baseflow.file.TrackedFolder':
@@ -420,6 +425,8 @@ class Project(flow.Object):
     
     def _register_runners(self):
         self._RUNNERS_FACTORY.ensure_runner_type(Blender)
+        self._RUNNERS_FACTORY.ensure_runner_type(Palas)
+        self._RUNNERS_FACTORY.ensure_runner_type(Houdoo)
         self._RUNNERS_FACTORY.ensure_runner_type(SessionWorker)
         self._RUNNERS_FACTORY.ensure_runner_type(DefaultEditor)
     
