@@ -13,6 +13,11 @@ class Shot(BaseShot):
         expanded=True
     )
 
+    @classmethod
+    def get_source_display(cls, oid):
+        split = oid.split('/')
+        return f'{split[3]} · {split[5]}'
+
     def ensure_tasks(self):
         """
         Creates the tasks of this shot based on the task
@@ -27,6 +32,11 @@ class Shot(BaseShot):
         
         self.tasks.touch()
 
+    def get_default_contextual_edits(self, context_name):
+        if context_name == 'settings':
+            sequence, shot = self.name().rsplit('_', maxsplit=1)
+            return dict(sequence=sequence, shot=shot)
+
 
 class Shots(ShotCollection):
 
@@ -38,7 +48,4 @@ class Shots(ShotCollection):
         s = super(Shots, self).add(name, object_type)
         s.ensure_tasks()
 
-
-class Sequence(BaseSequence):
-    
-    shots = flow.Child(Shots).ui(expanded=True)
+        return s
